/*
 *  
 *  $Id: iconos.h 4367 2011-11-04 10:58:44Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once
#include "ico_imagen.h"
#include "ico_estudio.h"
#include "ico_serie.h"
#include "historial.h"
#include "historial_open.h"
#include "hombre.h"
#include "iconos.h"
#include "mujer.h"
#include "otro.h"
#include "ico_fichero_clave.h"
#include "ico_plegar.h"
#include "ico_desplegar.h"
#include "ico_movie_preview.h"
#include "ico_clean_all.h"
#include "ico_all_patients.h"
